@@ -227,6 +227,7 @@ public class GMXAndWebDeAPIStep extends AbstractStep<Contact[], Object> implemen
      * @return
      */
     private List<Contact> parseJSONIntoContacts(String allContactsPage) {
+    	System.out.println(allContactsPage);
         List<Contact> contacts = new ArrayList<Contact>();
         try {
             JSONObject allContentJSON = new JSONObject(allContactsPage);
@@ -259,7 +260,7 @@ public class GMXAndWebDeAPIStep extends AbstractStep<Contact[], Object> implemen
                     //setting the displayname
                     contact.setDisplayName(contact.getGivenName() + " " + contact.getSurName());
 
-                    if (JSONObject.NULL != contactJSON.get("birthday") && contactJSON.has("birthday")) {
+                    if (contactJSON.hasAndNotNull("birthday")/* && JSONObject.NULL != contactJSON.get("birthday")*/) {
                         JSONObject birthdayJSON = contactJSON.getJSONObject("birthday");
                         String day = "";
                         String month = "";
@@ -281,177 +282,178 @@ public class GMXAndWebDeAPIStep extends AbstractStep<Contact[], Object> implemen
                             calendar.set(1970, Integer.parseInt(month) - 1, Integer.parseInt(day));
                             contact.setBirthday(calendar.getTime());
                         }
+                    }
 
-                        if (contactJSON.has("location")) {
-                            final JSONArray addressesJSON = contactJSON.getJSONArray("location");
-                            for (int a = 0; a < addressesJSON.length(); a++) {
-                                final JSONObject addressJSON = addressesJSON.getJSONObject(a);
-                                if (addressJSON.has("classifier")) {
-                                    final JSONObject classifier = addressJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (addressJSON.has("address")) {
-                                                contact.setStreetBusiness(addressJSON.getString("address"));
-                                            }
-                                            if (addressJSON.has("postcode")) {
-                                                contact.setPostalCodeBusiness(addressJSON.getString("postcode"));
-                                            }
-                                            if (addressJSON.has("town")) {
-                                                contact.setCityBusiness(addressJSON.getString("town"));
-                                            }
-                                            if (addressJSON.has("country")) {
-                                                contact.setCountryBusiness(addressJSON.getString("country"));
-                                            }
-                                        } else if (type.equals("PRIVATE")) {
-                                            if (addressJSON.has("address")) {
-                                                contact.setStreetHome(addressJSON.getString("address"));
-                                            }
-                                            if (addressJSON.has("postcode")) {
-                                                contact.setPostalCodeHome(addressJSON.getString("postcode"));
-                                            }
-                                            if (addressJSON.has("town")) {
-                                                contact.setCityHome(addressJSON.getString("town"));
-                                            }
-                                            if (addressJSON.has("country")) {
-                                                contact.setCountryHome(addressJSON.getString("country"));
-                                            }
+                    if (contactJSON.has("location")) {
+                        final JSONArray addressesJSON = contactJSON.getJSONArray("location");
+                        for (int a = 0; a < addressesJSON.length(); a++) {
+                            final JSONObject addressJSON = addressesJSON.getJSONObject(a);
+                            if (addressJSON.has("classifier")) {
+                                final JSONObject classifier = addressJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (addressJSON.has("address")) {
+                                            contact.setStreetBusiness(addressJSON.getString("address"));
+                                        }
+                                        if (addressJSON.has("postcode")) {
+                                            contact.setPostalCodeBusiness(addressJSON.getString("postcode"));
+                                        }
+                                        if (addressJSON.has("town")) {
+                                            contact.setCityBusiness(addressJSON.getString("town"));
+                                        }
+                                        if (addressJSON.has("country")) {
+                                            contact.setCountryBusiness(addressJSON.getString("country"));
+                                        }
+                                    } else if (type.equals("PRIVATE")) {
+                                        if (addressJSON.has("address")) {
+                                            contact.setStreetHome(addressJSON.getString("address"));
+                                        }
+                                        if (addressJSON.has("postcode")) {
+                                            contact.setPostalCodeHome(addressJSON.getString("postcode"));
+                                        }
+                                        if (addressJSON.has("town")) {
+                                            contact.setCityHome(addressJSON.getString("town"));
+                                        }
+                                        if (addressJSON.has("country")) {
+                                            contact.setCountryHome(addressJSON.getString("country"));
                                         }
                                     }
                                 }
                             }
                         }
-
-                        if (contactJSON.has("fax")) {
-                            final JSONArray faxesJSON = contactJSON.getJSONArray("fax");
-                            for (int a = 0; a < faxesJSON.length(); a++) {
-                                final JSONObject faxJSON = faxesJSON.getJSONObject(a);
-                                if (faxJSON.has("classifier")) {
-                                    final JSONObject classifier = faxJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (faxJSON.has("number")) {
-                                                contact.setFaxBusiness(faxJSON.getString("number"));
-                                            }
-                                        } else if (type.equals("PRIVATE")) {
-                                            if (faxJSON.has("number")) {
-                                                contact.setFaxHome(faxJSON.getString("number"));
-                                            }
-                                        }
-                                    }
-                                }
-                            }
-                        }
-
-                        if (contactJSON.has("messaging")) {
-                            final JSONArray messagingJSON = contactJSON.getJSONArray("messaging");
-                            for (int a = 0; a < messagingJSON.length(); a++) {
-                                final JSONObject instantMessengerJSON = messagingJSON.getJSONObject(a);
-                                if (instantMessengerJSON.has("classifier")) {
-                                    final JSONObject classifier = instantMessengerJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (instantMessengerJSON.has("messenger") && instantMessengerJSON.has("messengerAccount")) {
-                                                contact.setInstantMessenger1(instantMessengerJSON.getString("messengerAccount") + " (" + instantMessengerJSON.getString("messenger") + ")");
-                                            }
-                                        } else if (type.equals("PRIVATE")) {
-                                            if (instantMessengerJSON.has("messenger") && instantMessengerJSON.has("messengerAccount")) {
-                                                contact.setInstantMessenger2(instantMessengerJSON.getString("messengerAccount") + " (" + instantMessengerJSON.getString("messenger") + ")");
-                                            }
-                                        }
-                                    }
-                                }
-                            }
-                        }
-
-                        if (contactJSON.has("mobilePhone")) {
-                            final JSONArray mobilePhonesJSON = contactJSON.getJSONArray("mobilePhone");
-                            for (int a = 0; a < mobilePhonesJSON.length(); a++) {
-                                final JSONObject mobilePhoneJSON = mobilePhonesJSON.getJSONObject(a);
-                                if (mobilePhoneJSON.has("classifier")) {
-                                    final JSONObject classifier = mobilePhoneJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (mobilePhoneJSON.has("number")) {
-                                                contact.setCellularTelephone1(mobilePhoneJSON.getString("number"));
-                                            }
-                                        } else if (type.equals("PRIVATE")) {
-                                            if (mobilePhoneJSON.has("number")) {
-                                                contact.setCellularTelephone2(mobilePhoneJSON.getString("number"));
-                                            }
-                                        }
-                                    }
-                                }
-                            }
-                        }
-
-                        if (contactJSON.has("phone")) {
-                            final JSONArray phonesJSON = contactJSON.getJSONArray("phone");
-                            for (int a = 0; a < phonesJSON.length(); a++) {
-                                final JSONObject phoneJSON = phonesJSON.getJSONObject(a);
-                                if (phoneJSON.has("classifier")) {
-                                    final JSONObject classifier = phoneJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (phoneJSON.has("number")) {
-                                                contact.setTelephoneBusiness1(phoneJSON.getString("number"));
-                                            }
-                                        } else if (type.equals("PRIVATE")) {
-                                            if (phoneJSON.has("number")) {
-                                                contact.setTelephoneHome1(phoneJSON.getString("number"));
-                                            }
-                                        }
-                                    }
-                                }
-                            }
-                        }
-
-                        if (contactJSON.has("email")) {
-                            final JSONArray emailsJSON = contactJSON.getJSONArray("email");
-                            for (int a = 0; a < emailsJSON.length(); a++) {
-                                final JSONObject emailJSON = emailsJSON.getJSONObject(a);
-                                if (emailJSON.has("classifier")) {
-                                    final JSONObject classifier = emailJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (emailJSON.has("address")) {
-                                                contact.setEmail1(emailJSON.getString("address"));
-                                            }
-                                        } else if (type.equals("PRIVATE")) {
-                                            if (emailJSON.has("address")) {
-                                                contact.setEmail2(emailJSON.getString("address"));
-                                            }
-                                        }
-                                    }
-                                }
-                            }
-                        }
-
-                        if (contactJSON.has("url")) {
-                            final JSONArray urlsJSON = contactJSON.getJSONArray("phone");
-                            for (int a = 0; a < urlsJSON.length(); a++) {
-                                final JSONObject urlJSON = urlsJSON.getJSONObject(a);
-                                if (urlJSON.has("classifier")) {
-                                    final JSONObject classifier = urlJSON.getJSONObject("classifier");
-                                    if (classifier.has("name")) {
-                                        final String type = classifier.getString("name");
-                                        if (type.equals("BUSINESS")) {
-                                            if (urlJSON.has("uri")) {
-                                                contact.setURL(urlJSON.getString("uri"));
-                                            }
-                                        }
-                                    }
-                                }
-                            }
-
-                        }
                     }
 
+                    if (contactJSON.has("fax")) {
+                        final JSONArray faxesJSON = contactJSON.getJSONArray("fax");
+                        for (int a = 0; a < faxesJSON.length(); a++) {
+                            final JSONObject faxJSON = faxesJSON.getJSONObject(a);
+                            if (faxJSON.has("classifier")) {
+                                final JSONObject classifier = faxJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (faxJSON.has("number")) {
+                                            contact.setFaxBusiness(faxJSON.getString("number"));
+                                        }
+                                    } else if (type.equals("PRIVATE")) {
+                                        if (faxJSON.has("number")) {
+                                            contact.setFaxHome(faxJSON.getString("number"));
+                                        }
+                                    }
+                                }
+                            }
+                        }
+                    }
+
+                    if (contactJSON.has("messaging")) {
+                        final JSONArray messagingJSON = contactJSON.getJSONArray("messaging");
+                        for (int a = 0; a < messagingJSON.length(); a++) {
+                            final JSONObject instantMessengerJSON = messagingJSON.getJSONObject(a);
+                            if (instantMessengerJSON.has("classifier")) {
+                                final JSONObject classifier = instantMessengerJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (instantMessengerJSON.has("messenger") && instantMessengerJSON.has("messengerAccount")) {
+                                            contact.setInstantMessenger1(instantMessengerJSON.getString("messengerAccount") + " (" + instantMessengerJSON.getString("messenger") + ")");
+                                        }
+                                    } else if (type.equals("PRIVATE")) {
+                                        if (instantMessengerJSON.has("messenger") && instantMessengerJSON.has("messengerAccount")) {
+                                            contact.setInstantMessenger2(instantMessengerJSON.getString("messengerAccount") + " (" + instantMessengerJSON.getString("messenger") + ")");
+                                        }
+                                    }
+                                }
+                            }
+                        }
+                    }
+
+                    if (contactJSON.has("mobilePhone")) {
+                        final JSONArray mobilePhonesJSON = contactJSON.getJSONArray("mobilePhone");
+                        for (int a = 0; a < mobilePhonesJSON.length(); a++) {
+                            final JSONObject mobilePhoneJSON = mobilePhonesJSON.getJSONObject(a);
+                            if (mobilePhoneJSON.has("classifier")) {
+                                final JSONObject classifier = mobilePhoneJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (mobilePhoneJSON.has("number")) {
+                                            contact.setCellularTelephone1(mobilePhoneJSON.getString("number"));
+                                        }
+                                    } else if (type.equals("PRIVATE")) {
+                                        if (mobilePhoneJSON.has("number")) {
+                                            contact.setCellularTelephone2(mobilePhoneJSON.getString("number"));
+                                        }
+                                    }
+                                }
+                            }
+                        }
+                    }
+
+                    if (contactJSON.has("phone")) {
+                        final JSONArray phonesJSON = contactJSON.getJSONArray("phone");
+                        for (int a = 0; a < phonesJSON.length(); a++) {
+                            final JSONObject phoneJSON = phonesJSON.getJSONObject(a);
+                            if (phoneJSON.has("classifier")) {
+                                final JSONObject classifier = phoneJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (phoneJSON.has("number")) {
+                                            contact.setTelephoneBusiness1(phoneJSON.getString("number"));
+                                        }
+                                    } else if (type.equals("PRIVATE")) {
+                                        if (phoneJSON.has("number")) {
+                                            contact.setTelephoneHome1(phoneJSON.getString("number"));
+                                        }
+                                    }
+                                }
+                            }
+                        }
+                    }
+
+                    if (contactJSON.has("email")) {
+                        final JSONArray emailsJSON = contactJSON.getJSONArray("email");
+                        for (int a = 0; a < emailsJSON.length(); a++) {
+                            final JSONObject emailJSON = emailsJSON.getJSONObject(a);
+                            if (emailJSON.has("classifier")) {
+                                final JSONObject classifier = emailJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (emailJSON.has("address")) {
+                                            contact.setEmail1(emailJSON.getString("address"));
+                                        }
+                                    } else if (type.equals("PRIVATE")) {
+                                        if (emailJSON.has("address")) {
+                                            contact.setEmail2(emailJSON.getString("address"));
+                                        }
+                                    }
+                                }
+                            }
+                        }
+                    }
+
+                    if (contactJSON.has("url")) {
+                        final JSONArray urlsJSON = contactJSON.getJSONArray("phone");
+                        for (int a = 0; a < urlsJSON.length(); a++) {
+                            final JSONObject urlJSON = urlsJSON.getJSONObject(a);
+                            if (urlJSON.has("classifier")) {
+                                final JSONObject classifier = urlJSON.getJSONObject("classifier");
+                                if (classifier.has("name")) {
+                                    final String type = classifier.getString("name");
+                                    if (type.equals("BUSINESS")) {
+                                        if (urlJSON.has("uri")) {
+                                            contact.setURL(urlJSON.getString("uri"));
+                                        }
+                                    }
+                                }
+                            }
+                        }
+
+                    }
+
+
                     contacts.add(contact);
                     // An error in parsing one contact should not bring them all down
                 } catch (final JSONException e) {
