@@ -54,12 +54,14 @@ import java.util.Collection;
 import java.util.Date;
 import java.util.LinkedList;
 import java.util.List;
+import org.apache.commons.logging.Log;
 import org.microformats.hCard.HCard;
 import org.microformats.hCard.HCard.Address;
 import org.microformats.hCard.HCard.Email;
 import org.microformats.hCard.HCard.Tel;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.java.Strings;
+import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.tools.encoding.Base64;
 import com.openexchange.tools.versit.converter.ConverterException;
 import com.openexchange.tools.versit.converter.OXContainerConverter;
@@ -208,8 +210,17 @@ public class HCardToContactTransformer {
         }
         try {
             OXContainerConverter.loadImageFromURL(c, uri.toString());
-        } catch (ConverterException e) {
-            e.printStackTrace(); //TODO log error somewere, but don't fail. Simply don't store an image
+        } catch (final ConverterException e) {
+            // log error, but don't fail. Simply don't store an image
+            final Log LOG = com.openexchange.log.Log.loggerFor(HCardToContactTransformer.class);
+            LOG.warn("Couldn't load image.", e);
+            // Add warning
+            final Throwable cause = e.getCause();
+            if (null == cause) {
+                c.addWarning(SubscriptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage()));
+            } else {
+                c.addWarning(SubscriptionErrorMessage.UNEXPECTED_ERROR.create(cause, cause.getMessage()));
+            }
         }
     }
 
